==> 0.0.4.tar.gz: lib/package/checkbox.dart <==
import 'package:flutter/material.dart';

// ignore: must_be_immutable
class MillCheckBox extends StatelessWidget {
  MillCheckBox({
    Key key,
    @required this.value,
    @required this.onChange,
    this.label,
    this.fontSize = 18.0,
    this.size = 24,
    this.disabled = false,
    this.indeterminate = false,
    this.outside = 6,
    this.activeColor = const Color(0xff4362E7),
    this.labelStyle = const TextStyle(fontSize: 16, color: Color(0xff333333)),
  }) : super(key: key);
  final value;
  final onChange;
  final double size;
  final double outside;
  final Color activeColor;
  final bool indeterminate;
  final bool disabled;
  final String label;
  final double fontSize;
  final TextStyle labelStyle;

  @override
  Widget build(BuildContext context) {
    Color _borderColor = disabled ? Color(0xffdcdfe6) : Color(0xff666666);
    Color _backgroundColor = disabled ? Color(0xffedf2fc) : Color(0xffffffff);
    Color _activeIconColor = disabled ? Color(0xffc0c4cc) : Color(0xffffffff);
    Color _activeBackground = disabled ? Color(0xffedf2fc) : activeColor;
    Color _activeBorder = disabled ? Color(0xffdcdfe6) : activeColor;
    return GestureDetector(
        behavior: HitTestBehavior.translucent,
        onTap: () {
          if (!disabled && onChange != null) {
            onChange();
          }
        },
        child: Container(
          color: Colors.transparent,
          padding: EdgeInsets.only(top: outside, bottom: outside),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Stack(alignment: Alignment.center, //指定未定位或部分定位widget的对齐方式
                  children: [
                    Container(
                      width: size,
                      height: size,
                      decoration: BoxDecoration(
                          color: value || indeterminate
                              ? _activeBackground
                              : _backgroundColor,
                          borderRadius: BorderRadius.circular(3),
                          border: Border.all(
                              width: 1.0,
                              color: value || indeterminate
                                  ? _activeBorder
                                  : _borderColor)),
                    ),
                    Visibility(
                        visible: value,
                        child: Positioned(
                          left: 0,
                          top: 0,
                          child: Container(
                            width: size,
                            height: size,
                            child: Icon(
                                const IconData(0xe6bc,
                                    fontFamily: 'MilluiIcons'),
                                size: size * 0.45,
                                color: _activeIconColor),
                          ),
                        )),
                    Visibility(
                      visible: !value && indeterminate,
                      child: Positioned(
                        left: (size - size * 0.6) / 2,
                        top: size / 2,
                        child: Container(
                          height: 0,
                          width: size * 0.6,
                          decoration: BoxDecoration(
                              border: Border(
                            bottom: BorderSide(
                                width: size / 12, color: _activeIconColor),
                          )),
                        ),
                      ),
                    )
                  ]),
              label != null
                  ? Container(
                      padding: EdgeInsets.only(left: 10, bottom: 1.5),
                      child: Text(
                        label,
                        style: labelStyle.copyWith(fontSize: fontSize),
                      ),
                    )
                  : Container()
            ],
          ),
        ));
  }
}

==> 0.0.7.tar.gz: lib/package/checkbox.dart <==
import 'package:flutter/material.dart';

// ignore: must_be_immutable
class MillCheckBox extends StatelessWidget {
  MillCheckBox({
    Key key,
    @required this.value,
    @required this.onChange,
    this.label,
    this.fontSize = 18.0,
    this.size = 24,
    this.disabled = false,
    this.indeterminate = false,
    this.outside = 6,
    this.activeColor = const Color(0xff4362E7),
    this.labelStyle = const TextStyle(fontSize: 16, color: Color(0xff333333)),
  }) : super(key: key);
  final value;
  final onChange;
  final double size;
  final double outside;
  final Color activeColor;
  final bool indeterminate;
  final bool disabled;
  final String label;
  final double fontSize;
  final TextStyle labelStyle;

  @override
  Widget build(BuildContext context) {
    Color _borderColor = disabled ? Color(0xffdcdfe6) : Color(0xff666666);
    Color _backgroundColor = disabled ? Color(0xffedf2fc) : Color(0xffffffff);
    Color _activeIconColor = disabled ? Color(0xffc0c4cc) : Color(0xffffffff);
    Color _activeBackground = disabled ? Color(0xffedf2fc) : activeColor;
    Color _activeBorder = disabled ? Color(0xffdcdfe6) : activeColor;
    return GestureDetector(
        behavior: HitTestBehavior.opaque,
        onTap: () {
          if (!disabled && onChange != null) {
            onChange();
          }
        },
        child: Container(
          color: Colors.transparent,
          padding: EdgeInsets.only(top: outside, bottom: outside),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Stack(alignment: Alignment.center, //指定未定位或部分定位widget的对齐方式
                  children: [
                    Container(
                      width: size,
                      height: size,
                      decoration: BoxDecoration(
                          color: value || indeterminate
                              ? _activeBackground
                              : _backgroundColor,
                          borderRadius: BorderRadius.circular(3),
                          border: Border.all(
                              width: 1.0,
                              color: value || indeterminate
                                  ? _activeBorder
                                  : _borderColor)),
                    ),
                    Visibility(
                        visible: value,
                        child: Positioned(
                          left: 0,
                          top: 0,
                          child: Container(
                            width: size,
                            height: size,
                            child: Icon(
                                const IconData(0xe6bc,
                                    fontFamily: 'MilluiIcons'),
                                size: size * 0.45,
                                color: _activeIconColor),
                          ),
                        )),
                    Visibility(
                      visible: !value && indeterminate,
                      child: Positioned(
                        left: (size - size * 0.6) / 2,
                        top: size / 2,
                        child: Container(
                          height: 0,
                          width: size * 0.6,
                          decoration: BoxDecoration(
                              border: Border(
                            bottom: BorderSide(
                                width: size / 12, color: _activeIconColor),
                          )),
                        ),
                      ),
                    )
                  ]),
              label != null
                  ? Container(
                      padding: EdgeInsets.only(left: 10, bottom: 1.5),
                      child: Text(
                        label,
                        style: labelStyle.copyWith(fontSize: fontSize),
                      ),
                    )
                  : Container()
            ],
          ),
        ));
  }
}
